@@ -1,4 +1,3 @@
-# mypy: allow-untyped-defs
 from typing import Optional
 
 import torch
@@ -20,7 +19,7 @@ __MAX_ALG_ID: Optional[int] = None
 
 if _cusparselt is not None:
 
-    def _init():
+    def _init() -> bool:
         global __cusparselt_version
         global __MAX_ALG_ID
         if __cusparselt_version is None:
@@ -35,7 +34,7 @@ if _cusparselt is not None:
 
 else:
 
-    def _init():
+    def _init() -> bool:
         return False
 
 
